==> core_models-0.1.0.gem: app/controllers/core_models/base/currencies_controller.rb <==
require_dependency "core_models/core_models_controller"

module CoreModels
  class Base::CurrenciesController < CoreModelsController
    # GET /base/currencies
    # GET /base/currencies.json
    def index
      @base_currencies = Base::Currency.all

      respond_to do |format|
        format.html # index.html.erb
        format.json { render :json => @base_currencies }
      end
    end

    # GET /base/currencies/1
    # GET /base/currencies/1.json
    def show
      @base_currency = Base::Currency.find(params[:id])

      respond_to do |format|
        format.html # show.html.erb
        format.json { render :json => @base_currency }
      end
    end

    # GET /base/currencies/new
    # GET /base/currencies/new.json
    def new
      @base_currency = Base::Currency.new

      respond_to do |format|
        format.html # new.html.erb
        format.json { render :json => @base_currency }
      end
    end

    # GET /base/currencies/1/edit
    def edit
      @base_currency = Base::Currency.find(params[:id])
    end

    # POST /base/currencies
    # POST /base/currencies.json
    def create
      @base_currency = Base::Currency.new(params[:base_currency])

      respond_to do |format|
        if @base_currency.save
          format.html { redirect_to @base_currency, :notice => 'Currency was successfully created.' }
          format.json { render :json => @base_currency, :status => :created, :location => @base_currency }
        else
          format.html { render :action => "new" }
          format.json { render :json => @base_currency.errors, :status => :unprocessable_entity }
        end
      end
    end

    # PUT /base/currencies/1
    # PUT /base/currencies/1.json
    def update
      @base_currency = Base::Currency.find(params[:id])

      respond_to do |format|
        if @base_currency.update_attributes(params[:base_currency])
          format.html { redirect_to @base_currency, :notice => 'Currency was successfully updated.' }
          format.json { head :no_content }
        else
          format.html { render :action => "edit" }
          format.json { render :json => @base_currency.errors, :status => :unprocessable_entity }
        end
      end
    end

    # DELETE /base/currencies/1
    # DELETE /base/currencies/1.json
    def destroy
      @base_currency = Base::Currency.find(params[:id])
      @base_currency.destroy

      respond_to do |format|
        format.html { redirect_to base_currencies_url }
        format.json { head :no_content }
      end
    end
  end
end

==> core_models-0.2.9.gem: app/controllers/core_models/base/currencies_controller.rb <==
require_dependency "core_models/core_models_controller"

module CoreModels
  class Base::CurrenciesController < CoreModelsController
    # GET /base/currencies
    # GET /base/currencies.json
    def index
      @base_currencies = Base::Currency.all

      respond_to do |format|
        format.html # index.html.erb
        format.json { render :json => @base_currencies }
      end
    end

    # GET /base/currencies/1
    # GET /base/currencies/1.json
    def show
      @base_currency = Base::Currency.find(params[:id])

      respond_to do |format|
        format.html # show.html.erb
        format.json { render :json => @base_currency }
      end
    end

    # GET /base/currencies/new
    # GET /base/currencies/new.json
    def new
      @base_currency = Base::Currency.new

      respond_to do |format|
        format.html # new.html.erb
        format.json { render :json => @base_currency }
      end
    end

    # GET /base/currencies/1/edit
    def edit
      @base_currency = Base::Currency.find(params[:id])
    end

    # POST /base/currencies
    # POST /base/currencies.json
    def create
      @base_currency = Base::Currency.new(params[:base_currency])

      respond_to do |format|
        if @base_currency.save
          format.html { redirect_to @base_currency, :notice => 'Currency was successfully created.' }
          format.json { render :json => @base_currency, :status => :created, :location => @base_currency }
        else
          format.html { render :action => "new" }
          format.json { render :json => @base_currency.errors, :status => :unprocessable_entity }
        end
      end
    end

    # PUT /base/currencies/1
    # PUT /base/currencies/1.json
    def update
      @base_currency = Base::Currency.find(params[:id])

      respond_to do |format|
        if @base_currency.update(params[:base_currency])
          format.html { redirect_to @base_currency, :notice => 'Currency was successfully updated.' }
          format.json { head :no_content }
        else
          format.html { render :action => "edit" }
          format.json { render :json => @base_currency.errors, :status => :unprocessable_entity }
        end
      end
    end

    # DELETE /base/currencies/1
    # DELETE /base/currencies/1.json
    def destroy
      @base_currency = Base::Currency.find(params[:id])
      @base_currency.destroy

      respond_to do |format|
        format.html { redirect_to base_currencies_url }
        format.json { head :no_content }
      end
    end
  end
end
